library(envalysis)
library(lattice)
library(psych)
library(survival)
library(plyr)
library(ggplot2)
library(ggthemes)
library(tidyr)
library(Rmisc)
library(gridExtra)
library(extrafont)
library(jtools)
library(grid)
library(reshape)
library(scales)
library(pastecs)
library(nlme)
library(lme4)
library(sjmisc)
library(sjstats)
library(ggmcmc)
library(sjPlot)
library(ggeffects)
library(brms)
library(ICC)
library(shinystan)
library(car)
library(QuantPsyc)
library(eeptools)
library(brmstools)
library(dplyr)
library(here)
library(bayesplot)
library(loo)
library(rstan)
library(tidyverse)
library(Hmisc)
library(irr)
library(envalysis)
library(mcmcplots)
library(clickR)
library(sjPlot)
library(insight)
library(httr)

Data0 <- read.table("processed_dataset.txt", header=T)
View(Data0)
Demoinfo <- read.table("demographic_info.txt", header=T)

#Add demographic info
Data0 <- merge(Data0,Demoinfo, by.x=c("Victim"), by.y=c("Individual"), all.x=TRUE)
Data0 <- merge(Data0,Demoinfo, by.x=c("Aggressor"), by.y=c("Individual"), all.x=TRUE)

#create a binary 0/1 variable for consolation, reconciliation, renewed-aggression, as well as for AS/AG/Ps
Data0$Consolation.01 <- ifelse(Data0$Consolation > 0, 1,0)
Data0$Reconciliation.01 <- ifelse(Data0$Reconciliation > 0, 1,0)
Data0$Renewed_ag.01 <- ifelse(Data0$Renewed_ag > 0, 1,0)

Data0$Binary.P <- ifelse(Data0$Number.P > 0, 1,0)
Data0$Binary.AS <- ifelse(Data0$Number.AS > 0, 1,0)
Data0$Binary.AG <- ifelse(Data0$Number.AG > 0, 1,0)

#rename column names
Data0 <- as_tibble(Data0)
colnames(Data0)
names(Data0)[names(Data0) == "Age.x"] <- "Age_victim"
names(Data0)[names(Data0) == "Binary_ageclass.x"] <- "Binary_ageclass_victim"
names(Data0)[names(Data0) == "Binary_rankclass.x"] <- "Binary_rankclass_victim"
names(Data0)[names(Data0) == "Sex.x"] <- "Sex_victim"
names(Data0)[names(Data0) == "Rearing.x"] <- "Rearing_victim"
names(Data0)[names(Data0) == "Age.y"] <- "Age_aggressor"
names(Data0)[names(Data0) == "Binary_ageclass.y"] <- "Binary_ageclass_aggressor"
names(Data0)[names(Data0) == "Binary_rankclass.y"] <- "Binary_rankclass_aggressor"
names(Data0)[names(Data0) == "Sex.y"] <- "Sex_aggressor"
names(Data0)[names(Data0) == "Rearing.y"] <- "Rearing_aggressor"
colnames(Data0)
write.table(Data0, file="data_victimsignalling.txt", sep="\t")

#create two datasets to work with: One at Display level, one at Bout level (for later analysis)
Data.Display <- Data0[!Data0$Analysis_level == "Bout", ]
Data.Bout <- Data0[!Data0$Analysis_level == "Display", ]
Data.Display$Display_duration.s. <- as.numeric(Data.Display$Display_duration.s.)
str(Data.Display$Display_duration.s.)

#Descriptives and plots
mean(Data.Display$Victim)
summary(Data.Display$PC_ID, Data.Display$Victim)
table(Data0$Victim)
Data0 %>%
  summarise_each(funs(n_distinct))
prop.table(table(Data0$Consolation.01))
prop.table(table(Data0$Reconciliation.01))
prop.table(table(Data0$Renewed_ag.01))

summary(Data0$Number.gestures,na.rm=TRUE)
sd(Data0$Number.gestures,na.rm=TRUE)
sum(Data0$Number.gestures,na.rm=TRUE)

summary(Data0$Number.vocalizations,na.rm=TRUE)
sd(Data0$Number.vocalizations,na.rm=TRUE)
sum(Data0$Number.vocalizations,na.rm=TRUE)

summary(Data0$Number.facialEx,na.rm=TRUE)
sd(Data0$Number.facialEx,na.rm=TRUE)
sum(Data0$Number.facialEx,na.rm=TRUE)

summary(Data0$Number.Bodysig,na.rm=TRUE)
sd(Data0$Number.Bodysig,na.rm=TRUE)
sum(Data0$Number.Bodysig,na.rm=TRUE)

#How do victims communicate?

## Signal components plot

#Sum tot Number of signal types by victim ID
SumNumGest<-aggregate(Data.Display$Number.gestures, by=list(Data.Display$Victim), FUN=sum)
SumNumVoc<-aggregate(Data.Display$Number.vocalizations, by=list(Data.Display$Victim), FUN=sum)
SumNumFac<-aggregate(Data.Display$Number.facialEx, by=list(Data.Display$Victim), FUN=sum)
SumNumBody<-aggregate(Data.Display$Number.Bodysig, by=list(Data.Display$Victim), FUN=sum)

TotNum<-cbind(SumNumGest,SumNumVoc[,2],SumNumFac[,2],SumNumBody[,2])

colnames(TotNum)<-c("Victim", "Gestures", "Vocalizations", "Facial_expressions", "Body_signals")

Sum<-TotNum %>% replace(is.na(.), 0) %>% mutate(sum = rowSums(.[2:5]))

Sum$PropGest<-Sum$Gestures/Sum$sum*100
Sum$PropVoc<-Sum$Vocalizations/Sum$sum*100
Sum$PropFac<-Sum$Facial_expressions/Sum$sum*100
Sum$PropBod<-Sum$Body_signals/Sum$sum*100

Binary_AgeClass_Victim<-c("Adult","Adult","Adult","Immature","Adult","Immature","Immature","Immature","Adult","Immature","Adult","Adult","Adult","Adult","Adult","Immature","Immature","Adult","Immature","Immature","Adult","Immature","Immature","Adult","Immature","Immature","Immature")

Sum<-cbind(Sum,Binary_AgeClass_Victim)
write.table(Sum, file="Sum.txt", sep="\t")

#with "Sum" we transposed data so that dataset has 4 rows per individual 
#with summarized percent for each signal component
#once done, upload dataset
Data_signaltypes <- read.table("Signaltypes.txt", header=T)

Data_signaltypes$Binary_AgeClass_Victim <- factor(Data_signaltypes$Binary_AgeClass_Victi, levels = c("Immature", "Adult"))

Fig1.1 <-ggplot(Data_signaltypes, aes(x=Victim, y=Percentage, fill=Signaltype))+
  geom_bar(stat="identity")+
  facet_wrap(~Binary_AgeClass_Victim, drop = TRUE, scales= "free")+
  scale_fill_manual(name="Component type",values = alpha(c("lightblue", "#276dc2","darkgray", "black"), .7))+
  theme_publish(base_size = 20, base_family = "Arial", line_size = 0.25)+
  theme(text=element_text(size=25,family="Arial"))+ theme(legend.position="right",legend.text=element_text(size=25))+
  labs(title="A", x="")+theme(plot.margin = unit(c(0,1.8,0,1.5), "cm"))

## Signal component types plot
#Sum tot Number of signal types (AG/AS/P) by victim ID
SumNumP<-aggregate(Data.Display$Number.P, by=list(Data.Display$Victim), FUN=sum)
SumNumAS<-aggregate(Data.Display$Number.AS, by=list(Data.Display$Victim), FUN=sum)
SumNumAG<-aggregate(Data.Display$Number.AG, by=list(Data.Display$Victim), FUN=sum)
SumAgeclass<-aggregate(Data.Display$Binary_ageclass_victim, by=list(Data.Display$Victim), FUN=sum)

TotNumT<-cbind(SumNumP,SumNumAS[,2],SumNumAG[,2])

colnames(TotNumT)<-c("Victim", "Paedomorphic", "AffiliativeSubmissive", "Aggressive")

Binary_AgeClass_Victim<-c("Adult","Adult","Adult","Immature","Adult","Immature","Immature","Immature","Adult","Immature","Adult","Adult","Adult","Adult","Adult","Immature","Immature","Adult","Immature","Immature","Adult","Immature","Immature","Adult","Immature","Immature","Immature")

SumPASAG<-cbind(TotNumT,Binary_AgeClass_Victim)

SumPASAG<-SumPASAG %>% replace(is.na(.), 0) %>% mutate(sum = rowSums(.[2:4]))

SumPASAG$PropP<-SumPASAG$Paedomorphic/SumPASAG$sum*100
SumPASAG$PropAS<-SumPASAG$AffiliativeSubmissive/SumPASAG$sum*100
SumPASAG$PropAG<-SumPASAG$Aggressive/SumPASAG$sum*100

write.table(SumPASAG, file="SumPASAG.txt", sep="\t")
View(SumPASAG)

#with SumPASAG, we transposed data so that dataset has 3 rows per individual with summarized percentage for each signal component type!
#once done, upload dataset (already provided below)
Data_signaltypes_classifier <- read.table("Signaltypes_classifier.txt", header=T)

Data_signaltypes_classifier$Binary_AgeClass_Victim <- factor(Data_signaltypes_classifier$Binary_AgeClass_Victim, levels = c("Immature", "Adult"))

Fig1.2 <- ggplot(Data_signaltypes_classifier, aes(x=Victim, y=Percentage, fill=Signaltype_kind))+
  geom_bar(stat="identity")+
  facet_wrap(~Binary_AgeClass_Victim, drop = TRUE, scales= "free")+
  scale_fill_manual(name="Style category",values = alpha(c("orange", "red", "brown"), .5))+
  theme_publish(base_size = 20, base_family = "Arial", line_size = 0.25)+
  theme(text=element_text(size=25,family="Arial"))+ theme(legend.position="right", legend.text=element_text(size=25))+
  labs(title="B")+theme(plot.margin = unit(c(0,1,0,1.5), "cm"))

grid.arrange(Fig1.1,Fig1.2)

#descriptives display duration
summary(Data.Display$Display_duration.s.)
sd(Data.Display$Display_duration.s.)

#decriptive piloerection
table(Data.Display$Piloerection_display)


########## MODEL 1.1

#Define variables
colnames(Data.Display)
Data.Display$Binary.AG <- as.factor(Data.Display$Binary.AG)
Data.Display$Binary.P <- as.factor(Data.Display$Binary.P)
Data.Display$Consolation.01 <- as.factor(Data.Display$Consolation.01)
Data.Display$Piloerection_display <- as.factor(Data.Display$Piloerection_display)
Data.Display$Rearing_victim <- as.factor(Data.Display$Rearing_victim)
Data.Display$Binary_ageclass_victim <- as.factor(Data.Display$Binary_ageclass_victim)

str(Data.Display$Victim)
str(Data.Display$Aggressor)

#check datapoints 0/1 of Binary.AS
Data.Display$Binary.AS <- as.factor(Data.Display$Binary.AS)
table(Data.Display$Binary.AS)

#binary IVs, Model 1.1 (Consolation as DV); Binary.AS excluded as no datapoins of "0"
str(Data.Display)
model1.1 <- brm(formula = Consolation.01 ~ Aggression_severity+ Piloerection_display+Binary.P*Binary_ageclass_victim+ 
                  Binary.AG*Binary_ageclass_victim+ (1|Victim)+ (1|Aggressor), 
                data=Data.Display, family=bernoulli(),
                warmup= 2000, iter = 10000, chains = 4, control = list(adapt_delta = 0.99))
summary(model1.1)
launch_shinystan(model1.1)
prior_summary(model1.1)

#Victim rearing
model1.1VR <- brm(formula = Consolation.01 ~ Aggression_severity+ Piloerection_display+Binary.P*Binary_ageclass_victim+ 
                  Binary.AG*Binary_ageclass_victim+Rearing_victim+ (1|Victim)+ (1|Aggressor), 
                data=Data.Display, family=bernoulli(),
                warmup= 2000, iter = 10000, chains = 4, control = list(adapt_delta = 0.99))
summary(model1.1VR)

#LOOIC comparisons
loo1 <- loo(model1.1)
loo2 <- loo(model1.1VR)
loo_compare(loo2,loo1)


#model diagnostics
tail(sort(rstan::summary(model1.1$fit)$summary[,"Rhat"])) #all r hat <1.05?
head(sort(rstan::summary(model1.1$fit)$summary[,"n_eff"])) #all effective samples >100?
pp_check(model1.1) #does posterior distribution reflect real observations of response?
pp_checkmodel1 <- pp_check(model1.1, nsamples=1000)
traceplot_model1 <-plot(model1.1)#did chains behave well?

#get posterior distributions
posterior <- as.matrix(model1.1)

#apply differnt colorschemes:
#color_scheme_set("blue")
#color_scheme_set("gray")
#color_scheme_view("viridisC")
#color_scheme_set("darkgray")
d <- mcmc_intervals(posterior,
                pars=c("b_Binary_ageclass_victimimmature", "b_Piloerection_display1", "b_Aggression_severitySevere","b_Binary.P1","b_Binary.AG1",
                       "b_Binary.P1:Binary_ageclass_victimimmature", "b_Binary_ageclass_victimimmature:Binary.AG1"),
                prob=0.8,
                prob_outer=0.95,
                point_est = "mean")
Figure1_posterior <- d +scale_x_continuous(limits=c(-3.5,3.5),breaks=scales::pretty_breaks(n=8))+
  labs(x="Parameter estimate", y= " ", title="A")+
  theme(axis.text.y=element_blank())+ theme_publish(base_size = 16, base_family = "Arial", line_size = 0.4)+
  scale_y_discrete(labels=c("b_Binary_ageclass_victimimmature"="Age", "b_Piloerection_display1"="Piloerection", "b_Aggression_severitySevere"="Aggression severity",
                            "b_Binary.P1" = expression(~bold("Paedomorphic signals")), 
                            "b_Binary.AG1" = "Aggressive signals", 
                            "b_Binary.P1:Binary_ageclass_victimimmature"="Age x Paedomorphic signals", 
                            "b_Binary_ageclass_victimimmature:Binary.AG1"= "Age x Aggressive signals"))+
  theme(panel.grid = element_blank())+theme(axis.text.y=element_text(angle=50,size=16,hjust=1),axis.text.x=element_text(size=12))


#raw plot proportions 
Data_signaltypes <- read.table("BinaryPCons.txt", header=T)
colnames(Data_signaltypes)
setseed(8)

pd = position_dodge(0.75)
p <- ggplot(Data_signaltypes, aes(Binary.P, PropConsolation, color=Ageclass))+
  geom_point(aes(size=Observations),position=position_jitterdodge(),shape=16,alpha=0.4)+
  scale_y_continuous(limits=c(-0.1,1.0),breaks=scales::pretty_breaks(n=0))+
  theme_publish(base_size = 16, base_family = "Arial", line_size = 0.4)+
  scale_color_manual(values=c("black", "#1AA7EC"))+
  stat_summary(aes(colour=factor(Ageclass)),fun.y=mean, shape=18, size=5,  geom="point",position=pd)+
  stat_summary(aes(colour=factor(Ageclass)),fun.data = mean_se, geom = "errorbar",position=pd,width=0.2, size=1)+
  labs(color='')+
  geom_hline(yintercept=0.5, linetype="dashed", 
             color = "gray", size=0.5)+
  geom_vline(xintercept=1.5, linetype="dashed", 
             color = "gray", size=0.5)+
  theme(legend.position='none')+
  labs(x="Use of paedomorphic signals", y="Proportion consolation received",title="B")+
  theme(axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 70)))+scale_size(name = "N")
p




########## MODEL 1.2

colnames(Data.Display)
Data.Display$Binary.AG <- as.factor(Data.Display$Binary.AG)
Data.Display$Binary.P <- as.factor(Data.Display$Binary.P)
Data.Display$Consolation.01 <- as.factor(Data.Display$Consolation.01)
Data.Display$Reconciliation.01 <- as.factor(Data.Display$Reconciliation.01)
str(Data.Display$Victim)
str(Data.Display$Aggressor)
str(Data.Display$Study_year)
Data.Display$Study_year <- as.character(Data.Display$Study_year)
Data.Display$Piloerection_display <- as.factor(Data.Display$Piloerection_display)

#binary IVs, Model 1.2 (Reconciliation as DV); Binary.AS excluded as no datapoins of "0"
model1.2 <- brm(formula = Reconciliation.01 ~ Aggression_severity+Piloerection_display+Binary.P*Binary_ageclass_victim+ 
                  Binary.AG*Binary_ageclass_victim+ (1|Victim)+ (1|Aggressor), 
                data=Data.Display, family=bernoulli(),
                warmup= 2000, iter = 10000, chains = 4, control = list(adapt_delta = 0.99))
launch_shinystan(model1.2)
summary(model1.2)
prior_summary(model1.2)

#Victim rearing
model1.2VR <- brm(formula = Reconciliation.01 ~ Aggression_severity+ Piloerection_display+Binary.P*Binary_ageclass_victim+ 
                    Binary.AG*Binary_ageclass_victim+Rearing_victim+ (1|Victim)+ (1|Aggressor), 
                  data=Data.Display, family=bernoulli(),
                  warmup= 2000, iter = 10000, chains = 4, control = list(adapt_delta = 0.99))
summary(model1.2VR)

#LOOIC comparisons
loo1 <- loo(model1.2, reloo=TRUE)
loo2 <- loo(model1.2VR,reloo=TRUE)
loo_compare(loo1,loo2)


# Parameter estimation and model diagnostics
tail(sort(rstan::summary(model1.2$fit)$summary[,"Rhat"])) #all r hat <1.05?
head(sort(rstan::summary(model1.2$fit)$summary[,"n_eff"])) #all effective samples >100?
pp_check(model1.2) #does posterior distribution reflect real observations of response?
pp_check(model1.2, nsamples=1000)
plot(model1.2)#did chains behave well?

#get posterior distributions
posterior <- as.matrix(model1.2)

d <- mcmc_intervals(posterior,
                pars=c("b_Binary_ageclass_victimimmature", "b_Piloerection_display1", "b_Aggression_severitySevere","b_Binary.P1", "b_Binary.AG1",
                       "b_Binary.P1:Binary_ageclass_victimimmature", 
                       "b_Binary_ageclass_victimimmature:Binary.AG1"),
                prob=0.8,
                prob_outer=0.95,
                point_est = "mean")
Figure2_posterior <- d +scale_x_continuous(limits=c(-6,7),breaks=scales::pretty_breaks(n=8))+
  theme(text=element_text(size=16,family="sans",colour="black"))+
  labs(x="Parameter estimate",title="C")+
  theme(axis.text.y=element_blank())+
  scale_y_discrete(labels=c("b_Binary_ageclass_victimimmature"="Age",
    "b_Piloerection_display1"="Piloerection", "b_Aggression_severitySevere"="Aggression severity", 
                            "b_Binary.P1" = "Paedomorphic signals", 
                            "b_Binary.AG1" = "Aggressive signals", 
                            "b_Binary.P1:Binary_ageclass_victimimmature"="Age x Paedomorphic signals", 
                            "b_Binary_ageclass_victimimmature:Binary.AG1"= "Age x Aggressive signals"))+
  theme(panel.grid = element_blank())+theme(panel.grid = element_blank())+
  theme_publish(base_size = 16, base_family = "Arial", line_size = 0.4)+
  theme(axis.text.y=element_text(angle=50,size=16, hjust=1),axis.text.x=element_text(size=12))


#raw plot proportions 
Data_signaltypesRec <- read.table("BinaryPRec.txt", header=T)
colnames(Data_signaltypes)
setseed(8)

pd = position_dodge(0.75)
r <- ggplot(Data_signaltypesRec, aes(Binary.P, PropReconciliation, color=Ageclass))+
  geom_point(aes(size=Observations),position=position_jitterdodge(),shape=16,alpha=0.4)+
  scale_y_continuous(limits=c(-0.1,1.0),breaks=scales::pretty_breaks(n=0))+
  theme_publish(base_size = 16, base_family = "Arial", line_size = 0.4)+
  scale_color_manual(values=c("black", "#1AA7EC"))+
  stat_summary(aes(colour=factor(Ageclass)),fun.y=mean, shape=18, size=5, geom="point",position=pd)+
  stat_summary(aes(colour=factor(Ageclass)),fun.data = mean_se, geom = "errorbar",position=pd,width=0.2, size=1)+
  labs(color='')+
  geom_hline(yintercept=0.5, linetype="dashed", 
             color = "gray", size=0.5)+
  geom_vline(xintercept=1.5, linetype="dashed", 
             color = "gray", size=0.5)+
  theme(legend.position='none')+
  labs(x="Use of paedomorphic signals", y="Proportion reconciliation received",title="D")+
  theme(axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 50)))+scale_size(name = "N")

r



####### MODEL 1.3

#Define variables
colnames(Data.Display)
Data.Display$Binary.AG <- as.factor(Data.Display$Binary.AG)
Data.Display$Binary.P <- as.factor(Data.Display$Binary.P)
Data.Display$Consolation.01 <- as.factor(Data.Display$Consolation.01)
Data.Display$Reconciliation.01 <- as.factor(Data.Display$Reconciliation.01)
Data.Display$Renewed_ag.01 <- as.factor(Data.Display$Renewed_ag.01)
str(Data.Display$Victim)
str(Data.Display$Aggressor)
str(Data.Display$Study_year)
Data.Display$Study_year <- as.character(Data.Display$Study_year)
Data.Display$Piloerection_display <- as.factor(Data.Display$Piloerection_display)


#binary IVs, Model 1.3 (Renewed_ag.01 as DV); Binary.AS excluded as no datapoins of "0"
model1.3 <- brm(formula = Renewed_ag.01 ~ Aggression_severity+Piloerection_display+Binary.P*Binary_ageclass_victim+ 
                  Binary.AG*Binary_ageclass_victim+ (1|Victim)+ (1|Aggressor), 
                data=Data.Display, family=bernoulli(),
                warmup= 2000, iter = 10000, chains = 4, control = list(adapt_delta = 0.99))
launch_shinystan(model1.3)
prior_summary(model1.3)
summary(model1.3)

#Victim rearing
model1.3VR <- brm(formula = Renewed_ag.01 ~ Aggression_severity+ Piloerection_display+Binary.P*Binary_ageclass_victim+ 
                    Binary.AG*Binary_ageclass_victim+Rearing_victim+ (1|Victim)+ (1|Aggressor), 
                  data=Data.Display, family=bernoulli(),
                  warmup= 2000, iter = 10000, chains = 4, control = list(adapt_delta = 0.99))
summary(model1.3VR)

loo1 <- loo(model1.3, reloo=TRUE)
loo2 <- loo(model1.3VR, reloo=TRUE)
loo_compare(loo1,loo2)


#Parameter estimation and model diagnostics
tail(sort(rstan::summary(model1.3$fit)$summary[,"Rhat"])) #all r hat <1.05?
head(sort(rstan::summary(model1.3$fit)$summary[,"n_eff"])) #all effective samples >100?
pp_check(model1.3) #does posterior distribution reflect real observations of response?
pp_check(model1.3, nsamples=1000)
plot(model1.3)#did chains behave well?

#get posterior distributions
posterior <- as.matrix(model1.3)
dimnames(posterior)
d <- mcmc_intervals(posterior,
                pars=c("b_Binary_ageclass_victimimmature", "b_Piloerection_display1", "b_Aggression_severitySevere","b_Binary.P1", 
                       "b_Binary.AG1","b_Binary.P1:Binary_ageclass_victimimmature",
                       "b_Binary_ageclass_victimimmature:Binary.AG1"),
                prob=0.8,
                prob_outer=0.95,
                point_est = "mean")
Figure3_posterior <- d +scale_x_continuous(limits=c(-9,10),breaks=scales::pretty_breaks(n=8))+
  theme(text=element_text(size=16,family="sans",colour="black"))+
  labs(x="Parameter estimate",title="E")+
  theme(axis.text.y=element_blank())+
  scale_y_discrete(labels=c("b_Binary_ageclass_victimimmature"="Age", "b_Piloerection_display1"="Piloerection", 
                            "b_Aggression_severitySevere"="Aggression severity","b_Binary.P1" = "Paedomorphic signals",
                            "b_Binary.AG1" = "Aggressive signals", 
                            "b_Binary.P1:Binary_ageclass_victimimmature"= expression(~bold("Age x Paedomorphic signals")), 
                            "b_Binary_ageclass_victimimmature:Binary.AG1"= "Age x Aggressive signals"))+
  theme(panel.grid = element_blank())+theme_publish(base_size = 16, base_family = "Arial", line_size = 0.4)+
  theme(axis.text.y=element_text(angle=50,size=16, hjust=1),axis.text.x=element_text(size=10))


#raw plot proportions 
Data_signaltypesAG <- read.table("BinaryPRenewedAG.txt", header=T)
str(Data_signaltypesAG)
set.seed(8)
Data_signaltypesAG$Binary.P <- as.factor(Data_signaltypesAG$Binary.P)
a <- ggplot(Data_signaltypesAG, aes(Binary.P, PropRenAG, color=Ageclass))+
  geom_point(aes(size=Observations),position=position_jitterdodge(),shape=16,alpha=0.4)+
  scale_y_continuous(limits=c(0.0,1.0),breaks=scales::pretty_breaks(n=0))+
  theme_publish(base_size = 16, base_family = "Arial", line_size = 0.4)+
  scale_color_manual(values=c("black", "#1AA7EC"))+
  stat_summary(aes(colour=factor(Ageclass)),fun.y=mean, shape=18, size=5,  geom="point",position=pd)+
  stat_summary(aes(colour=factor(Ageclass)),fun.data = mean_se, geom = "errorbar",position=pd,width=0.2, size=1)+
  labs(color=' ')+
  geom_hline(yintercept=0.5, linetype="dashed", 
             color = "gray", size=0.5)+
  geom_vline(xintercept=1.5, linetype="dashed", 
             color = "gray", size=0.5)+
  labs(x="Use of paedomorphic signals", y="Proportion renewed aggression received",title="F")+
  theme(legend.position = c(0.7, 0.9))+
  theme(axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 60)))+scale_size(name = "N")
a

#summary plot
grid.arrange(Figure1_posterior,Figure2_posterior,Figure3_posterior,p,r,a, ncol=3)



###############MODEL 1.4

#Upload corresponding dataset
DataASO <- read.table("data_victimsignalling_BoutAso.txt", header=T)
DataASO$Consolation_afterbout <- as.factor(DataASO$Consolation_afterbout)
DataASO$Reconciliation_afterbout <- as.factor(DataASO$Reconciliation_afterbout)
DataASO$Bout_persistence <- as.factor(DataASO$Bout_persistence)

#binary IVs, Model 1.4 
model1.4<- brm(formula = Bout_persistence ~ Aggression_severity+Piloerection_bout+Consolation_afterbout*Binary_ageclass_victim +
                  (1|Victim)+ (1|Aggressor)+ (1|PC_ID), 
               data=DataASO, family=bernoulli(),
               warmup= 2000, iter = 10000, chains = 4, control = list(adapt_delta = 0.99))
summary(model1.4)
launch_shinystan(model1.4)
prior_summary(model1.4)

#Victim rearing
model1.4VR <- brm(formula = Bout_persistence ~ Aggression_severity+Piloerection_bout+Consolation_afterbout*Binary_ageclass_victim +
                    Rearing_victim+(1|Victim)+ (1|Aggressor)+ (1|PC_ID), 
                  data=DataASO, family=bernoulli(),
                  warmup= 2000, iter = 10000, chains = 4, control = list(adapt_delta = 0.99))
summary(model1.4VR)

#LOOIC comparisons
loo1 <- loo(model1.4)
loo2 <- loo(model1.4VR)
loo_compare(loo1,loo2)


#Diagnostics
tail(sort(rstan::summary(model1.4$fit)$summary[,"Rhat"])) #all r hat <1.05?
head(sort(rstan::summary(model1.4$fit)$summary[,"n_eff"])) #all effective samples >100?
pp_check(model1.4) #does posterior distribution reflect real observations of response?
pp_check(model1.4, nsamples=1000)
plot(model1.4)#did chains behave well?


#get posterior distributions
posterior <- as.matrix(model1.4)
d <- mcmc_intervals(posterior,
                pars=c("b_Binary_ageclass_victimimmature", "b_Piloerection_bout", "b_Aggression_severitySevere","b_Consolation_afterbout1"
                       ,"b_Consolation_afterbout1:Binary_ageclass_victimimmature"),
                prob_outer=0.95,
                prob=0.8,
                point_est = "mean")
Figure4_posterior <- d +scale_x_continuous(limits=c(-4,4),breaks=scales::pretty_breaks(n=8))+
  theme(text=element_text(size=16,family="sans",colour="black"))+
  labs(x="Parameter estimate", y=" ",title="A")+
  theme(axis.text.y=element_blank())+
  scale_y_discrete(labels=c("b_Binary_ageclass_victimimmature"="Age", "b_Piloerection_bout"=expression(~bold("Piloerection")), 
                            "b_Aggression_severitySevere"="Aggression severity","b_Consolation_afterbout1" = expression(~bold("Consolation received (CR)")),
                            "b_Consolation_afterbout1:Binary_ageclass_victimimmature"= expression(~bold("Age x CR"))))+
  theme(panel.grid = element_blank())+theme_publish(base_size = 16, base_family = "Arial", line_size = 0.4)+
  theme(axis.text.y=element_text(angle=50,size=16, hjust=1),axis.text.x=element_text(size=10))


#raw plot proportions: Figure S3
Data_propASOrec <- read.table("Prop_BoutAso_rec.txt", header=T)
colnames(Data_propASOrec)
setseed(8)

pd = position_dodge(0.75)
r <- ggplot(Data_propASOrec, aes(x=Reconciliation_received, y=Proppersistence, color=Ageclass))+
  geom_point(aes(size=Observations),position=position_jitterdodge(),shape=16,alpha=0.4)+
  scale_y_continuous(limits=c(0.0,1.0),breaks=scales::pretty_breaks(n=0))+
  theme_publish(base_size = 16, base_family = "Arial", line_size = 0.4)+
  stat_summary(aes(colour=factor(Ageclass)),fun.y=mean, shape=18, size=5,  geom="point",position=pd)+
  stat_summary(aes(colour=factor(Ageclass)),fun.data = mean_se, geom = "errorbar",position=pd,width=0.2, size=1)+
  scale_color_manual(values=c("black", "#1AA7EC"))+
  labs(color=' ')+
  geom_hline(yintercept=0.5, linetype="dashed", 
             color = "gray", size=0.5)+
  geom_vline(xintercept=1.5, linetype="dashed", 
             color = "gray", size=0.5)+
  theme(legend.position = c(0.8, 0.9))+
  labs(x="Reconciliation received", y="Proportion of signaling persistence ",title="")+
  theme(axis.title.y = element_text(margin = margin(t = 0, r = 0, b = 0, l = 30)))+scale_size(name = "N")
r

#raw plot proportions for paper
Data_propASOcon <- read.table("Prop_BoutAso_cons.txt", header=T)
colnames(Data_propASOcon)
setseed(8)

pd = position_dodge(0.75)
c <- ggplot(Data_propASOcon, aes(x=Consolation_received, y=Proppersistence, color=Ageclass))+
  geom_point(aes(size=Observations),position=position_jitterdodge(),shape=16,alpha=0.4)+
  scale_y_continuous(limits=c(0.0,1.0),breaks=scales::pretty_breaks(n=0))+
  theme_publish(base_size = 16, base_family = "Arial", line_size = 0.4)+
  stat_summary(aes(colour=factor(Ageclass)),fun.y=mean, shape=18, size=5,  geom="point",position=pd)+
  stat_summary(aes(colour=factor(Ageclass)),fun.data = mean_se, geom = "errorbar",position=pd,width=0.2, size=1)+
  scale_color_manual(values=c("black", "#1AA7EC"))+
  labs(color='')+
  geom_hline(yintercept=0.5, linetype="dashed", 
             color = "gray", size=0.5)+
  geom_vline(xintercept=1.5, linetype="dashed", 
             color = "gray", size=0.5)+
  theme(legend.position = c(0.8, 0.9))+
  labs(x="Consolation received", y="Proportion of signaling persistence",title="B")+
  theme(axis.title.y = element_text(margin = margin(t = 0, r = 0.5, b = 0, l = 30)))+scale_size(name = "N")
c

grid.arrange(Figure4_posterior,c, ncol=2)


############### MODEL 1.5

#use dataset produced via R 
Data_AudComp <- read.table("data_victimsignalling.txt", header=TRUE)

#create dataset at display level and bout 
Data_AudComp.Display <- Data_AudComp[!Data_AudComp$Analysis_level == "Bout", ]
str(Data_AudComp.Display)
Data_AudComp.Bout <- Data_AudComp[!Data_AudComp$Analysis_level == "Display", ]
str(Data_AudComp.Bout)

#Model 4: Do bonobos adapt emotional signal class (AG/P/AS) to the composition of the audience (FRIENDS/Dominants)?
#total number
str(Data_AudComp.Display)
str(Data_AudComp.Display$Binary_ageclass_victim)
str(Data_AudComp.Display$Aggression_severity)
str(Data_AudComp.Display$Friends_within_10m.01)
str(Data_AudComp.Display$Victim)
str(Data_AudComp.Display$Aggressor)
str(Data_AudComp.Display$Study_year)
Data_AudComp.Display$Kin_within10m.01 <- as.factor(Data_AudComp.Display$Kin_within10m.01)
Data_AudComp.Display$Piloerection_display <- as.factor(Data_AudComp.Display$Piloerection_display)
Data_AudComp.Display$N_friends_within10m <- as.numeric(Data_AudComp.Display$N_friends_within10m)
Data_AudComp.Display$Number.AG <- as.numeric(Data_AudComp.Display$Number.AG)
Data_AudComp.Display$Number.P <- as.numeric(Data_AudComp.Display$Number.P)
Data_AudComp.Display$Number.AS <- as.numeric(Data_AudComp.Display$Number.AS)
Data_AudComp.Display$Proportion.AS <- as.numeric(Data_AudComp.Display$Proportion.AS)
Data_AudComp.Display$Proportion.AG <- as.numeric(Data_AudComp.Display$Proportion.AG)
Data_AudComp.Display$Proportion.P <- as.numeric(Data_AudComp.Display$Proportion.P)
str(Data_AudComp.Display$Kin_within10m.01 )


#Info: For two conflicts we could not find audience composition in Zanna's original data file, thus less data points
model1.5<- brm(formula = Total_signals ~  Aggression_severity+Piloerection_display+Audience_0.10m*Binary_ageclass_victim+ 
                 N_friends_within10m* Binary_ageclass_victim+  Kin_within10m.01*Binary_ageclass_victim+
                 (1|Victim)+ (1|Aggressor), 
               data=Data_AudComp.Display, family=negbinomial(),
               warmup= 2000, iter = 10000, chains = 4, control = list(adapt_delta = 0.99))
summary(model1.5)
launch_shinystan(model1.5)
prior_summary(model1.5)


#Victim rearing
model1.5VR <- brm(formula =  Total_signals ~  Aggression_severity+Piloerection_display+Audience_0.10m*Binary_ageclass_victim+ 
                    N_friends_within10m* Binary_ageclass_victim+  Kin_within10m.01*Binary_ageclass_victim+
                    Rearing_victim+(1|Victim)+ (1|Aggressor)+ (1|PC_ID), 
                  data=Data_AudComp.Display, family=negbinomial(),
                  warmup= 2000, iter = 10000, chains = 4, control = list(adapt_delta = 0.99))
summary(model1.5VR)

#LOOIC 
loo1 <- loo(model1.5, reloo=TRUE)
loo2 <- loo(model1.5VR, reloo=TRUE)
loo_compare(loo1,loo2)

#Diagnostics
mcmc_plot(model1.5)
mcmc_plot(model1.5, type = "hist", pars = "^b_")
plot_model(model1.5, pars="^b_")
mcmc_plot(model1.5, pars = "^b_", prob_outer = 0.95)
posterior_interval(model1.5, pars = NA, prob = 0.95)
pp_check(model1.5, nsamples = 1000)+scale_x_continuous(limits=c(0,350),breaks=scales::pretty_breaks(n=8))
plot(model1.5)#did chains behave well?


#get posterior plot
posterior <- as.matrix(model1.5)
dimnames(posterior)
d <- mcmc_intervals(posterior,
                    pars=c("b_Audience_0.10m:Binary_ageclass_victimimmature", 
                           "b_Binary_ageclass_victimimmature:N_friends_within10m", 
                           "b_Binary_ageclass_victimimmature:Kin_within10m.011", 
                           "b_N_friends_within10m",
                           "b_Kin_within10m.011",
                           "b_Binary_ageclass_victimimmature", "b_Piloerection_display1", 
                           "b_Aggression_severitySevere",
                           "b_Audience_0.10m"),
                    prob=0.8,
                    prob_outer=0.95,
                    point_est = "mean")
Figure5_posterior <- d +scale_x_continuous(limits=c(-2,2))+
  theme(text=element_text(size=16,family="sans",colour="black"))+
  labs(x="Parameter estimate", y=" ",title="A")+
  theme(axis.text.y=element_blank())+
  scale_y_discrete(labels=c("b_Binary_ageclass_victimimmature"="Age", "b_Piloerection_display1"="Piloerection", 
                            "b_Aggression_severitySevere"="Aggression severity",
                            "b_Audience_0.10m" = "Audience within 10m",
                            "b_N_friends_within10m" ="Friends within 10m",
                            "b_Kin_within10m.011"="Kin within 10m",
                            "b_Audience_0.10m:Binary_ageclass_victimimmature"="Audience 10m X Age",
                   "b_Binary_ageclass_victimimmature:N_friends_within10m" =expression(~bold("Friends 10m X Age")), 
                   "b_Binary_ageclass_victimimmature:Kin_within10m.011" = "Kin 10m X Age"))+
  theme_publish(base_size = 16, base_family = "Arial", line_size = 0.4)+
  theme(axis.text.y=element_text(angle=30,size=16, hjust=1),axis.text.x=element_text(size=10))


#predicted values audience within 10m
summary(Data_AudComp.Display$Audience_0.10m)
xlevels <- list(Audience_0.10m=seq(from=1, to =19,length.out=100))
pdata <- marginal_effects(model1.5, effects = "Audience_0.10m:Binary_ageclass_victim", int_conditions = xlevels)
write.table(pdata$`Audience_0.10m`, file="marginal_effects_Audience_0.10m.txt", sep="\t")
tab <- read.table("marginal_effects_Audience_0.10m.txt", 
                  header=TRUE)
dfm <- data.frame(tab)
head(dfm)
s <- ggplot(Data_AudComp.Display, aes(x=Audience_0.10m,y=Total_signals, 
                              fill=Binary_ageclass_victim,
                              colour=Binary_ageclass_victim))+
  geom_point(alpha=0.5, size=3)+labs(x="Audience members within 10m",   y="Signal number",  title="B") +
  theme(text=element_text(size=18,family="serif"))+
  theme_publish(base_size = 16, base_family = "Arial", line_size = 0.4)+
  geom_ribbon(data=dfm, aes(ymin = lower__, ymax = upper__), 
              alpha=0.5,colour = NA)  +
  geom_line(data=dfm,aes(x=Audience_0.10m, y=estimate__))+
  scale_colour_manual(values=c("black", "#1AA7EC"))+
  scale_fill_manual(values=c("black", "#1AA7EC"))+
  theme(legend.position = c(0.2, 0.95))+
  theme(axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 20)))+
  theme(legend.title=element_blank())+
  theme(legend.title=element_blank(),legend.position = "none")
s


#predicted values friends within 10m
summary(Data_AudComp.Display$N_friends_within10m)
xlevels <- list(N_friends_within10m=seq(from=1, to =5,length.out=100))
pdata <- marginal_effects(model1.5, effects = "N_friends_within10m:Binary_ageclass_victim", int_conditions = xlevels)
write.table(pdata$`N_friends_within10m:Binary_ageclass_victim`, file="marginal_effects_friends_0.10m.txt", sep="\t")
tab <- read.table("marginal_effects_friends_0.10m.txt", 
                  header=TRUE)
dfm <- data.frame(tab)
head(dfm)
f <- ggplot(Data_AudComp.Display, aes(x=N_friends_within10m,y=Total_signals, 
                                      fill=Binary_ageclass_victim,
                                      colour=Binary_ageclass_victim))+
  geom_point(alpha=0.5, size=3)+labs(x="Friends within 10m",   y="Signal number",  title="C") +
  theme(text=element_text(size=18,family="serif"))+
  theme_publish(base_size = 16, base_family = "Arial", line_size = 0.4)+
  geom_ribbon(data=dfm, aes(ymin = lower__, ymax = upper__), 
              alpha=0.5,colour = NA)  +
  geom_line(data=dfm,aes(x= N_friends_within10m, y=estimate__))+
  scale_colour_manual(values=c("black", "#1AA7EC"))+
  scale_fill_manual(values=c("black", "#1AA7EC"))+
  theme(legend.title=element_blank(),legend.position = "none")+
  theme(axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 20)))
f


############ MODEL 1.6

model1.6<- brm(formula = Display_duration.s. ~  Aggression_severity+Piloerection_display+Audience_0.10m*Binary_ageclass_victim + 
                 N_friends_within10m* Binary_ageclass_victim+ Kin_within10m.01*Binary_ageclass_victim+
                 (1|Victim)+ (1|Aggressor), 
               data=Data_AudComp.Display, family=lognormal(),
               warmup= 2000, iter = 10000, chains = 4, control = list(adapt_delta = 0.99))
summary(model1.6)
launch_shinystan(model1.6)
prior_summary(model1.6)

#Victim rearing
model1.6VR <- brm(formula =  Display_duration.s. ~  Aggression_severity+Piloerection_display+Audience_0.10m*Binary_ageclass_victim + 
                    N_friends_within10m* Binary_ageclass_victim+ Kin_within10m.01*Binary_ageclass_victim+
                    Rearing_victim+(1|Victim)+ (1|Aggressor)+ (1|PC_ID), 
                  data=Data_AudComp.Display, family=lognormal(),
                  warmup= 2000, iter = 10000, chains = 4, control = list(adapt_delta = 0.99))
summary(model1.6VR)#terrible convergence, divergent chains

#LOOIC comparisons
loo1 <- loo(model1.6, reloo=TRUE)
loo2 <- loo(model1.6VR, reloo=TRUE)
loo_compare(loo1,loo2)


#Diagnostics
mcmc_plot(model1.6)
mcmc_plot(model1.6, type = "hist", pars = "^b_")
plot_model(model1.6, pars="^b_")
mcmc_plot(model1.6, pars = "^b_", prob_outer = 0.95)
posterior_interval(model1.6, pars = NA, prob = 0.95)
pp_check(model1.6, nsamples = 1000)+scale_x_continuous(limits=c(0,1000),breaks=scales::pretty_breaks(n=8))
plot(model1.6)#did chains behave well?


#get posterior plot
colnames(Data.Display)
posterior <- as.matrix(model1.6)
dimnames(posterior)
d <- mcmc_intervals(posterior,
                    pars=c("b_Audience_0.10m:Binary_ageclass_victimimmature", 
                           "b_Binary_ageclass_victimimmature:N_friends_within10m", 
                           "b_Binary_ageclass_victimimmature:Kin_within10m.011", 
                           "b_N_friends_within10m",
                           "b_Kin_within10m.011",
                           "b_Binary_ageclass_victimimmature", "b_Piloerection_display1", 
                           "b_Aggression_severitySevere",
                           "b_Audience_0.10m"),
                    prob=0.8,
                    prob_outer=0.95,
                    point_est = "mean")
Figure6_posterior <- d +scale_x_continuous(limits=c(-3,3),breaks=scales::pretty_breaks(n=8))+
  theme(text=element_text(size=16,family="sans",colour="black"))+
  labs(x="Parameter estimate", y=" ",title="D")+
  theme(axis.text.y=element_blank())+
  scale_y_discrete(labels=c("b_Binary_ageclass_victimimmature"="Age", "b_Piloerection_display1"="Piloerection", 
                            "b_Aggression_severitySevere"="Aggression severity",
                            "b_Audience_0.10m" = expression(~bold("Audience within 10m")),
                            "b_N_friends_within10m" ="Friends within 10m",
                            "b_Kin_within10m.011"="Kin within 10m",
                            "b_Audience_0.10m:Binary_ageclass_victimimmature"="Audience 10m X Age",
                            "b_Binary_ageclass_victimimmature:N_friends_within10m" = "Friends 10m X Age", 
                            "b_Binary_ageclass_victimimmature:Kin_within10m.011" = "Kin 10m X Age"))+
  theme_publish(base_size = 16, base_family = "Arial", line_size = 0.4)+
  theme(axis.text.y=element_text(angle=30,size=16, hjust=1),axis.text.x=element_text(size=10))


#predicted values audience within 10m
summary(Data_AudComp.Display$Audience_0.10m)
xlevels <- list(Audience_0.10m=seq(from=1, to =20,length.out=100))
pdata <- marginal_effects(model1.6, effects = "Audience_0.10m:Binary_ageclass_victim", int_conditions = xlevels)
write.table(pdata$`Audience_0.10m`, file="marginal_effects_Audience_0.10m.txt", sep="\t")
tab <- read.table("marginal_effects_Audience_0.10m.txt", 
                  header=TRUE)
dfm <- data.frame(tab)
head(dfm)
d <- ggplot(Data_AudComp.Display, aes(x=Audience_0.10m,y=Display_duration.s., 
                              fill=Binary_ageclass_victim,
                              colour=Binary_ageclass_victim))+
  geom_point(alpha=0.5, size=3)+labs(x="Audience members within 10m",   y="Signal display duration (s)",  title="E") +
  theme(text=element_text(size=18,family="serif"))+
  theme_publish(base_size = 16, base_family = "Arial", line_size = 0.4)+
  geom_ribbon(data=dfm, aes(ymin = lower__, ymax = upper__), 
              alpha=0.5,colour = NA)  +
  geom_line(data=dfm,aes(x=Audience_0.10m, y=estimate__))+
  scale_colour_manual(values=c("black", "#1AA7EC"))+
  scale_fill_manual(values=c("black", "#1AA7EC"))+
  theme(legend.title=element_blank(),legend.position = "none")+
  theme(axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 20)))
d

#predicted values friends within 10m
summary(Data_AudComp.Display$N_friends_within10m)
xlevels <- list(N_friends_within10m=seq(from=1, to =5,length.out=100))
pdata <- marginal_effects(model1.6, effects = "N_friends_within10m:Binary_ageclass_victim", int_conditions = xlevels)
write.table(pdata$`N_friends_within10m:Binary_ageclass_victim`, file="marginal_effects_friends_0.10m2.txt", sep="\t")
tab <- read.table("marginal_effects_friends_0.10m2.txt", 
                  header=TRUE)
dfm <- data.frame(tab)
head(dfm)
g <- ggplot(Data_AudComp.Display, aes(x=N_friends_within10m,y=Display_duration.s., 
                                      fill=Binary_ageclass_victim,
                                      colour=Binary_ageclass_victim))+
  geom_point(alpha=0.5, size=3)+labs(x="Friends within 10m",   y="Signal display duration (s)",  title="F") +
  theme(text=element_text(size=18,family="serif"))+
  theme_publish(base_size = 16, base_family = "Arial", line_size = 0.4)+
  geom_ribbon(data=dfm, aes(ymin = lower__, ymax = upper__), 
              alpha=0.5,colour = NA)  +
  geom_line(data=dfm,aes(x= N_friends_within10m, y=estimate__))+
  scale_colour_manual(values=c("black", "#1AA7EC"))+
  scale_fill_manual(values=c("black", "#1AA7EC"))+
  theme(legend.position = c(0.9, 0.9))+
  theme(axis.title.y = element_text(margin = margin(t = 0, r = 10, b = 0, l = 20)))+
  theme(legend.title=element_blank())
g

#summary plot
grid.arrange(Figure5_posterior,s,f,Figure6_posterior,d,g, ncol=3)


